@@ -12,7 +12,7 @@ our @ISA = qw( Exporter Net::Peep::Client );
 our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
-our $VERSION = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.4 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use constant DEFAULT_PID_FILE => "/var/run/sysmonitor.pid";
 
@@ -183,7 +183,7 @@ Collin Starkweather <collin.starkweather@colorado.edu>
 
 =head1 SEE ALSO
 
-perl(1), peepd(1), Net::Peep::BC, Net::Peep::Log, Net::Peep::Parse, Net::Peep::Client, sysmonitor.
+perl(1), peepd(1), Net::Peep::BC, Net::Peep::Log, Net::Peep::Parser, Net::Peep::Client, sysmonitor.
 
 http://peep.sourceforge.net
 
@@ -203,6 +203,12 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 =head1 CHANGE LOG
 
 $Log: Sysmonitor.pm,v $
+Revision 1.4  2001/07/23 17:46:29  starky
+Added versioning to the configuration file as well as the ability to
+specify groups in addition to / as a replacement for event letters.
+Also changed the Net::Peep::Parse namespace to Net::Peep::Parser.
+(I don't know why I ever named an object by a verb!)
+
 Revision 1.3  2001/05/07 02:39:19  starky
 A variety of bug fixes and enhancements:
 o Fixed bug 421729:  Now the --output flag should work as expected and the
